@@ -19,15 +19,16 @@ int ArraySource::itemCount() const
 
 QVariant ArraySource::item(int index) const
 {
-    if (!m_wrap && (index < 0 || index > m_array.count() - 1))
-        return QVariant{};
+    if (!m_wrap && (index < 0 || index > m_array.count() - 1)) {
+        return {};
+    }
 
     return m_array.at(index % m_array.count());
 }
 
 QVariant ArraySource::minimum() const
 {
-    auto itr = std::min_element(m_array.cbegin(), m_array.cend());
+    auto itr = std::min_element(m_array.cbegin(), m_array.cend(), variantCompare);
     if (itr != m_array.cend()) {
         return *itr;
     }
@@ -36,7 +37,7 @@ QVariant ArraySource::minimum() const
 
 QVariant ArraySource::maximum() const
 {
-    auto itr = std::max_element(m_array.cbegin(), m_array.cend());
+    auto itr = std::max_element(m_array.cbegin(), m_array.cend(), variantCompare);
     if (itr != m_array.cend()) {
         return *itr;
     }
@@ -72,3 +73,5 @@ void ArraySource::setWrap(bool wrap)
     m_wrap = wrap;
     Q_EMIT dataChanged();
 }
+
+#include "moc_ArraySource.cpp"
