@@ -21,32 +21,16 @@ public:
     ~LineChartMaterial();
 
     QSGMaterialType *type() const override;
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QSGMaterialShader *createShader() const override;
+#else
+    QSGMaterialShader *createShader(QSGRendererInterface::RenderMode) const override;
+#endif
+    int compare(const QSGMaterial *other) const override;
 
-    QColor lineColor() const;
-    QColor fillColor() const;
-    float lineWidth() const;
-    float aspect() const;
-    float smoothing() const;
-    QVector<QVector2D> points() const;
-    QVector2D bounds() const;
-
-    void setLineColor(const QColor &color);
-    void setFillColor(const QColor &color);
-    void setLineWidth(float width);
-    void setPoints(const QVector<QVector2D> &points);
-    void setAspect(float aspect);
-    void setSmoothing(float smoothing);
-    void setBounds(float min, float max);
-
-private:
-    QColor m_lineColor;
-    QColor m_fillColor;
-    float m_lineWidth = 0.0;
-    float m_aspect = 1.0;
-    float m_smoothing = 0.1;
-    QVector2D m_bounds;
-    QVector<QVector2D> m_points;
+    float aspect = 1.0;
+    float lineWidth = 0.0;
+    float smoothing = 0.1;
 };
 
 class LineChartShader : public SDFShader
@@ -55,6 +39,7 @@ public:
     LineChartShader();
     ~LineChartShader();
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     char const *const *attributeNames() const override;
 
     void initialize() override;
@@ -63,14 +48,12 @@ public:
 private:
     int m_matrixLocation = 0;
     int m_opacityLocation = 0;
-    int m_lineColorLocation = 0;
-    int m_fillColorLocation = 0;
     int m_lineWidthLocation = 0;
-    int m_pointsLocation = 0;
-    int m_pointCountLocation = 0;
     int m_aspectLocation = 0;
-    int m_boundsLocation = 0;
     int m_smoothingLocation = 0;
+#else
+    bool updateUniformData(QSGMaterialShader::RenderState &state, QSGMaterial *newMaterial, QSGMaterial *oldMaterial) override;
+#endif
 };
 
 #endif // LINECHARTMATERIAL_H
